@@ -7,14 +7,16 @@ from .api_endpoint import APIEndpoint
 
 
 class GetEndpoint(APIEndpoint):
-    def __init__(self, api, route, qs_args_def, body_args_def, business_class, authorization_object=None):
+    def __init__(self, api, route, qs_args_def, body_args_def, business_class, authentication_required=True,
+                 authorization_object=None, req_token='access'):
         if '_id' in route:
             @api.route(route)
             class ItemGet(Resource):
 
                 @RequestUtilities.try_except
+                @APIAuth.auth_required(authentication_required=authentication_required,
+                                       authorization_object=authorization_object, req_token=req_token)
                 @RequestArgsValidator.args_validation(qs_args_def, body_args_def)
-                @APIAuth.auth_required(authorization_object=authorization_object)
                 def get(self, _id):
                     return business_class.run()
         else:
@@ -22,7 +24,8 @@ class GetEndpoint(APIEndpoint):
             class ItemGet(Resource):
 
                 @RequestUtilities.try_except
+                @APIAuth.auth_required(authentication_required=authentication_required,
+                                       authorization_object=authorization_object, req_token=req_token)
                 @RequestArgsValidator.args_validation(qs_args_def, body_args_def)
-                @APIAuth.auth_required(authorization_object=authorization_object)
                 def get(self):
                     return business_class.run()
